###################################################
### chunk number 1: start up things
###################################################
set.seed(20061001,kind="Mersenne-Twister")
options(width=60,SweaveSyntax="SweaveSyntaxNoweb")
dir.create("report")
dir.create("figs")              


###################################################
### chunk number 2: load STAR get STAR doc directory path
###################################################
library(STAR)
vigdir <- system.file("doc",package="STAR")


###################################################
### chunk number 3: copy some figures from STAR doc to figs directory
###################################################
wd <- getwd()
src <- paste(vigdir,"/sc1.png",sep="")
dest <- paste(wd,"/figs/sc1.png",sep="")
file.copy(src,dest,FALSE)
src <- paste(vigdir,"/sc2.png",sep="")
dest <- paste(wd,"/figs/sc2.png",sep="")
file.copy(src,dest,FALSE)
src <- paste(vigdir,"/sc3.png",sep="")
dest <- paste(wd,"/figs/sc3.png",sep="")
file.copy(src,dest,FALSE)
src <- paste(vigdir,"/PouzatChaffiol_STARdraft.bib",sep="")
dest <- paste(wd,"/PouzatChaffiol_STARdraft.bib",sep="")
file.copy(src,dest,FALSE)


###################################################
### chunk number 4: Nb Fct in STAR
###################################################
nbSTARfct <- length(ls("package:STAR"))-dim(data(package="STAR")$results)[1]


###################################################
### chunk number 5: isi sorting 1
###################################################
myISI <- c(0.031,0.062,0.073,0.092,0.054)
names(myISI) <- paste(1:5)
myISI


###################################################
### chunk number 6: isi sorting 2
###################################################
rank(myISI) 
#myISIs <- sort.int(myISI,index.return=TRUE)
#myISIs$x


###################################################
### chunk number 7: isi sorting 3
###################################################
sort(myISI)


###################################################
### chunk number 8: run time of spontaneous analysis
###################################################
sdNames <- c("e060517spont","e060817spont","e060824spont","e070528spont")

onSingleSet <- function(setN) {
  cmd <- parse(text=paste("data(",setN,")",sep=""))
  eval(cmd)
  cmd <- parse(text=paste("assign(\"spontD\",",setN,")",sep=""))
  eval(cmd)
  nbSpikes <- sapply(spontD,length)
  rtt <- sapply(spontD, function(l) {
                        runtime <- system.time(renewalTestPlot(l))[3]
                        dev.off()
                        runtime
                        }
               )
  ft <- sapply(spontD, function(l) system.time(compModels(l,plot=FALSE))[3])
  rpt <- sapply(1:length(spontD),
                  function (stIdx) {
                    system.time(reportHTML(object=spontD[[stIdx]],
                                           directory="report",
                                           filename=paste(setN,"_",stIdx,sep=""),
                                           otherST=spontD[-stIdx],
                                           laglim=c(-1,1)*0.25,
                                           forceTT=FALSE,
                                           maxiter=60)
                               )[3]
                   }
               )
  result <- data.frame(nbSpikes=nbSpikes,
                       renewalTestTime=rtt,
                       fitTime=ft,
                       report=rpt)
  rownames(result) <- paste(setN,"_",1:length(spontD),sep="")
  result
}
pResult <- lapply(sdNames,onSingleSet)
spontStats <- data.frame(N=unlist(lapply(pResult, function(l) l$nbSpikes)),
                         Renewal=unlist(lapply(pResult, function(l) l$renewalTestTime)),
                         Fit=unlist(lapply(pResult, function(l) l$fitTime)),
                         Report=unlist(lapply(pResult, function(l) l$report))
                         )
rownames(spontStats) <- unlist(lapply(pResult,rownames))


###################################################
### chunk number 9: quick regressions on spontStats
###################################################
slopeRenewal <- as.vector(round(coef(lm(Renewal~N,data=spontStats))[2]*1000,digits=2))
slopeFit <- as.vector(round(coef(lm(Fit~N,data=spontStats))[2]*1000,digits=2))
slopeReport <- as.vector(round(coef(lm(Report~N,data=spontStats))[2]*1000))


###################################################
### chunk number 10: spont stats table
###################################################
library(xtable)
print(xtable(spontStats,label="spontStats",caption="Summary statistics of spontaneous spike train analysis. N: The number of spikes. Renewal: Time (s) required to carry out the computation and to generate the renewal test plot (Sec. \\ref{sec:renewalTestPlot}). Fit: Time (s) required to fit the 6 duration density models (Sec. \\ref{sec:bivariateDurationDistributionsFits}). Report: Time (s) required to generate an HTML report as detailed in Sec. \\ref{sec:autoReportForSpont}")) 


###################################################
### chunk number 11: run time of stimulus response analysis
###################################################
srNames <- c("e060517ionon",
             "e060817citron",
             "e060817terpi",
             "e060817mix",
             "e060824citral",
             "e070528citronellal")

onSingleSetB <- function(setN) {
  cmd <- parse(text=paste("data(",setN,")",sep=""))
  eval(cmd)
  cmd <- parse(text=paste("assign(\"responseD\",",setN,")",sep=""))
  eval(cmd)
  nbSpikes <- sapply(responseD,function(l) sum(sapply(l,length)))
  nbStim <- sapply(responseD, length)
  timeMax <- sapply(responseD, function(l) ceiling(max(unlist(l))))
  gst <- sapply(responseD,
                function(l) system.time(gsspsth0(l))[3]
                )
  rpt <- sapply(1:length(responseD),
                function (nIdx) {
                  l <- responseD[[nIdx]]
                  system.time(reportHTML(object=l,
                                         directory="report",
                                         filename=paste(setN,"_",nIdx,sep=""),
                                         stim=attr(l,"stimTimeCourse"),
                                         doTimeTransformation=FALSE
                                         )
                              )[3]
                }
                                         
                )
  result <- data.frame(nbSpikes=nbSpikes,
                       nbStim=nbStim,
                       Duration=timeMax,
                       spsth=gst,
                       report=rpt)
  rownames(result) <- paste(setN,"_",1:length(responseD),sep="")
  result
}
pResultB <- lapply(srNames,onSingleSetB)
responseStats <- data.frame(N=unlist(lapply(pResultB, function(l) l$nbSpikes)),
                            S=unlist(lapply(pResultB, function(l) l$nbStim)),
                            Duration=unlist(lapply(pResultB, function(l) l$Duration)),
                            SPSTH=unlist(lapply(pResultB, function(l) l$spsth)),
                            Report=unlist(lapply(pResultB, function(l) l$report))
                            )
rownames(responseStats) <- unlist(lapply(pResultB,rownames))


###################################################
### chunk number 12: quick regressions on spontStats
###################################################
slopeSPSTH <- as.vector(round(coef(lm(SPSTH~N,data=responseStats))[2]*1000,digits=2))
slopeReport2 <- as.vector(round(coef(lm(Report~N,data=responseStats))[2]*1000,digits=2))


###################################################
### chunk number 13: stim stats table
###################################################
print(xtable(responseStats,label="responseStats",caption="Summary statistics of stimulus response analysis. N: The total number of spikes. S: The number of stimulations. Duration: Duration (s) of the acquisition for each stimulation. SPSTH: Time (s) required to compute the \\GSSPSTH. Report: Time (s) required to generate an HTML report.")) 


###################################################
### chunk number 14: bin width 1
###################################################
simpleFit <- function(rt, bw, lwr=5, upr=10,...) {
  rtN <- deparse(substitute(rt))
  result <- gsspsth0(as.repeatedTrain(lapply(rt,function(l) l[lwr < l & l < upr])),
                     binSize=bw,...)[c("freq","ciUp","ciLow","mids")]
  class(result) <- "simpleFit"
  result$name <- rtN
  result$bw <- bw
  result$call <- match.call()
  result
}

plot.simpleFit <- function(x,y,...) plot(x$mids,x$freq,xlab="Time (s)",ylab="Freq. (Hz)",...)
lines.simpleFit <- function(x,...) lines(x$mids,x$freq,...)
ribbon <- function(object,...) polygon(c(object$mids,rev(object$mids)),
                                       c(object$ciUp,rev(object$ciLow)),
                                       ...)
  


###################################################
### chunk number 15: bin width 2
###################################################
bwList <- lapply(e060817mix, function(rt) lapply(c(0.025,0.005), function(bw) simpleFit(rt,bw,maxiter=60)))


###################################################
### chunk number 16: bin width 3
###################################################
pdf(file="figs/binWidth.pdf",width=10,height=12)


###################################################
### chunk number 17: bin width 4
###################################################
layout(matrix(1:3,nrow=3))
opar <- par(cex=1.002)
mainV <- paste("e060817mix_",1:3,sep="")
invisible(sapply(1:3,
                 function(idx) {
                   lc <- bwList[[idx]][[1]]
                   lf <- bwList[[idx]][[2]]
                   ylim=c(0,max(lc$ciUp))
                   plot(lc,type="n",ylim=ylim,main=mainV[idx],xaxs="i",yaxs="i")
                   ribbon(lc,col="grey80",border=NA)
                   lines(lf)
                 }
                 )
          )
par(opar)


###################################################
### chunk number 18: bin width 5
###################################################
dev.off()


###################################################
### chunk number 19: load STAR for demo eval=FALSE
###################################################
## library(STAR)


###################################################
### chunk number 20: search
###################################################
search()


###################################################
### chunk number 21: data use eval=FALSE
###################################################
## data(e070528spont)


###################################################
### chunk number 22: assign myURL
###################################################
myURL <- "http://www.biomedicale.univ-paris5.fr/physcerv/C_Pouzat/STAR_folder"


###################################################
### chunk number 23: assign myFileName
###################################################
myFileName <- "e070528spontN1.txt"


###################################################
### chunk number 24: assign myFileName bis eval=FALSE
###################################################
## myFileName = "e070528spontN1.txt"


###################################################
### chunk number 25: form full data names
###################################################
myFullName <- paste(myURL,"/",myFileName,sep="")


###################################################
### chunk number 26: load data of neuron 1 in the spontaneous regime eval=FALSE
###################################################
## ##<<load data of neuron 1 in the spontaneous regime>>=
## e070528spontN1 <- scan(myFullName,skip=5)


###################################################
### chunk number 27: load data in working directory eval=FALSE
###################################################
## e070528spontN1 <- scan("e070528spontN1.txt",skip=5)


###################################################
### chunk number 28: make a spikeTrain out of e070528spontN1 eval=FALSE
###################################################
## e070528spontN1 <- as.spikeTrain(e070528spontN1)


###################################################
### chunk number 29: class of e070528spont
###################################################
class(e070528spont)


###################################################
### chunk number 30: length of e070528spont
###################################################
length(e070528spont)


###################################################
### chunk number 31: names of e070528spont
###################################################
names(e070528spont)


###################################################
### chunk number 32: accessing list components by index eval=FALSE
###################################################
## e070528spont[[4]]


###################################################
### chunk number 33: accessing list components by index eval=FALSE
###################################################
## e070528spont[["neuron 4"]]


###################################################
### chunk number 34: sapply class on e070528spont
###################################################
sapply(e070528spont, class)


###################################################
### chunk number 35: sapply length on e070528spont
###################################################
sapply(e070528spont, length)


###################################################
### chunk number 36: plot.spikeTrain 1 eval=FALSE
###################################################
## plot.spikeTrain(e070528spont[["neuron 4"]])


###################################################
### chunk number 37: plot.spikeTrain eval=FALSE
###################################################
## plot(e070528spont[["neuron 4"]])


###################################################
### chunk number 38: prepare plot spike train
###################################################
pdf(file="figs/e070528spontN4_ST.pdf",width=8,height=8)
##e070528spont[[4]]
##dev.off()


###################################################
### chunk number 39: plot spike train
###################################################
plot(e070528spont[[4]])


###################################################
### chunk number 40: close plot spike train
###################################################
dev.off()


###################################################
### chunk number 41: print.spikeTrain 1 eval=FALSE
###################################################
## e070528spont[[4]]


###################################################
### chunk number 42: print.spikeTrain 2 eval=FALSE
###################################################
## print.spikeTrain(e070528spont[[4]])


###################################################
### chunk number 43: plot of e070528spontN1 eval=FALSE
###################################################
## plot(e070528spontN1)


###################################################
### chunk number 44: unclass e070528spontN1 eval=FALSE
###################################################
## e070528spontN1 <- unclass(e070528spontN1)


###################################################
### chunk number 45: plot of e070528spontN1 bis eval=FALSE
###################################################
## plot(e070528spontN1)


###################################################
### chunk number 46: prepare renewalTestPlot
###################################################
pdf(file="figs/e070528spontN4_RT.pdf",width=8,height=8)
##e070528spont[[4]]
##dev.off()


###################################################
### chunk number 47: renewalTestPlot
###################################################
renewalTestPlot(e070528spont[[4]])


###################################################
### chunk number 48: close renewalTestPlot
###################################################
dev.off()


###################################################
### chunk number 49: pkDataSet1 demo eval=FALSE
###################################################
## demo(package="STAR")
## demo(pkDataSet1)


###################################################
### chunk number 50: prepare lag isi plot
###################################################
pdf(file="figs/e070528spontN4_lagISIplot.pdf",width=8,height=8)


###################################################
### chunk number 51: illustrate isi lag plot
###################################################
n4.isi <- diff(e070528spont[["neuron 4"]])
plot(n4.isi[-length(n4.isi)],
     n4.isi[-1],
     pch=".",
     xlab=expression(i[j]),
     ylab=expression(i[j+1])
     )
     


###################################################
### chunk number 52: close lag isi plot
###################################################
dev.off()


###################################################
### chunk number 53: prepare compModels
###################################################
if (!exists("compN1Results")) 
  pdf(file="figs/e070528spontN1_CM.pdf",width=8,height=8)



###################################################
### chunk number 54: compModels
###################################################
if (!exists("compN1Results")) 
  compN1Results <- compModels(e070528spont[[1]])


###################################################
### chunk number 55: dummy compModels eval=FALSE
###################################################
## compModels(e070528spont[[1]])


###################################################
### chunk number 56: print compN1Results
###################################################
compN1Results


###################################################
### chunk number 57: close compModels
###################################################
if (!is.null(dev.list())) dev.off()


###################################################
### chunk number 58: prepare isiHistFit
###################################################
pdf(file="figs/e070528spontN1_isiFit.pdf",width=8,height=8)


###################################################
### chunk number 59: isiHistFit
###################################################
isiHistFit(e070528spont[[1]],"invgauss",xlim=c(0,0.5))


###################################################
### chunk number 60: close isiHistFit
###################################################
dev.off()


###################################################
### chunk number 61: isiHist4ST eval=FALSE
###################################################
## isiHist4ST <- function(mySpikeTrain,...) hist(diff(mySpikeTrain),...) 


###################################################
### chunk number 62: isiHist4ST eval=FALSE
###################################################
## hist.spikeTrain <- function(mySpikeTrain,...) hist(diff(mySpikeTrain),...) 


###################################################
### chunk number 63: load e070528citronellal eval=FALSE
###################################################
## data(e070528citronellal)


###################################################
### chunk number 64: prepare repeatedTrain print plot demo
###################################################
pdf(file="figs/e070528citronellalN1_PrintPlot.pdf",width=10,height=5)
layout(matrix(1:2,nrow=1))
plot(e070528citronellal[["neuron 1"]],
     main="Raster plot")


###################################################
### chunk number 65: repeatedTrain print plot demo 1 eval=FALSE
###################################################
## e070528citronellal[["neuron 1"]]


###################################################
### chunk number 66: repeatedTrain print plot demo 2
###################################################
plot(e070528citronellal[["neuron 1"]],
     stim=c(6.14,6.64),
     main="e070528citronellal[[\"neuron 1\"]]")


###################################################
### chunk number 67: close repeatedTrain print plot demo
###################################################
dev.off()


###################################################
### chunk number 68: prepare psth demo
###################################################
pdf(file="figs/e070528citronellalN1_psth.pdf",width=10,height=5)
layout(matrix(1:2,nrow=1))


###################################################
### chunk number 69: psth demo
###################################################
psth(e070528citronellal[[1]],
     breaks=seq(0,13,0.250),
     colCI=2,ylim=c(0,120),
     sub="bin width: 250 ms",
     stim=c(6.14,6.64))
psth(e070528citronellal[[1]],
     breaks=seq(0,13,0.025),
     colCI=2,
     ylim=c(0,120),
     sub="bin width: 25 ms",
     stim=c(6.14,6.64))


###################################################
### chunk number 70: close psth demo
###################################################
dev.off()


###################################################
### chunk number 71: get gsspsth0 of neuron 1 of e070528citronellal
###################################################
##<<get gsspsth0 of neuron 1 of e070528citronellal>>=
n1CitrGSSPSTH0 <- gsspsth0(e070528citronellal[[1]])


###################################################
### chunk number 72: prepare gsspsth0 demo
###################################################
pdf(file="figs/e070528citronellalN1_gsspsth0Demo.pdf",width=10,height=5)
layout(matrix(1:2,nrow=1))


###################################################
### chunk number 73: compare preprocessed with smooth for gsspsth0 1
###################################################
##<<compare preprocessed with smooth for gsspsth0 1>>=
X <- n1CitrGSSPSTH0$mids
Counts <- n1CitrGSSPSTH0$counts
theBS <- diff(X)[1]
nbTrials <- n1CitrGSSPSTH0$nbTrials
Y <- n1CitrGSSPSTH0$lambdaFct(X)*theBS*nbTrials


###################################################
### chunk number 74: compare preprocessed with smooth for gsspsth0 2
###################################################
plot(X,Counts,type="h",
     xlab="Time (s)",ylab="Counts per bin",
     main="Preprocessed data and smooth estimate")
lines(X,Y,col=2,lwd=1)


###################################################
### chunk number 75: plot gsspsth0
###################################################
plot(n1CitrGSSPSTH0,colCI=2,lwd=1,
     stim=c(6.14,6.64),
     ylim=c(0,120))


###################################################
### chunk number 76: close gsspsth0 demo
###################################################
dev.off()


###################################################
### chunk number 77: reportHTML.spikeTrain example 1 eval=FALSE
###################################################
## reportHTML(object=e070528spont[["neuron 4"]],
##            directory="report",
##            filename="e070528spont_4",
##            otherST=e070528spont[-4],
##            laglim=c(-1,1)*0.25,
##            forceTT=FALSE)


###################################################
### chunk number 78: reportHTML.spikeTrain example 2 eval=FALSE
###################################################
## reportHTML(object=e070528spont[["neuron 4"]],
##            directory="report",
##            filename="e070528spont_4",
##            otherST=e070528spont[-4],
##            laglim=c(-1,1)*0.25,
##            forceTT=FALSE,
##            maxiter=60)


###################################################
### chunk number 79: reportHTML.repeatedTrain example eval=FALSE
###################################################
## ##<<reportHTML.repeatedTrain example,results=hide>>=
## reportHTML(object=e070528citronellal[["neuron 1"]],
##            directory="report",
##            filename="e070528citronellal_1",
##            stim=c(6.14,6.64)
##           )


###################################################
### chunk number 80: seesionInfo
###################################################
sessionInfo()


###################################################
### chunk number 81: wPLS functions
###################################################
ss_lambdaFixed <- function(y,
                           x,
                           lambda,
                           w) {

  rk <- function(x,y) {
    k2 <- function(x) ((x - 0.5)^2 - 1/12)/2
    k4 <- function(x) ((x - 0.5)^4 - (x - 0.5)^2/2 + 7/240)/24
    k2(x) * k2(y) - k4(abs(x - y))
  }

  S <- cbind(rep(1,length(x)),x-0.5)
  Q <- outer(x,x,rk)
  
  if (!missing(w)) {
    S <- diag(sqrt(w)) %*% S
    y <- sqrt(w) * y
    Q <- diag(sqrt(w)) %*% Q %*% diag(sqrt(w))
  } else {
    w <- NULL
  }
  
  Sqr <- qr(S)
  R <- qr.R(Sqr)
  theQ <- qr.Q(Sqr,complete=TRUE)
  tF1 <- t(theQ[,1:2])
  F2 <- theQ[,-(1:2)]
  rm(theQ,Sqr)

  n <- length(y)
  G <- chol(t(F2)%*%Q%*%F2+n*lambda*diag(n-2))
  u <- forwardsolve(t(G),t(F2)%*%y)
  ## u <- backsolve(G,t(F2)%*%y)
  v <- backsolve(G,u)
  ## v <- forwardsolve(t(G),u)
  c <- F2 %*% v
  
  rightMember <- (tF1 %*% y) - (tF1 %*% Q %*% c)
  d <- backsolve(R,rightMember)
  result <- list(x=x,
                 y=y,
                 lambda=lambda,
                 w=w,
                 n=n,
                 d=d,
                 c=c
                 )
  ## rm(S,Q,G,tF1,F2,u,v,rightMember,c,d,lambda,n,R,w,x,y)
  environment(rk) <- globalenv()
  result$rk <- rk
  class(result) <- "simpleSmooth"
  result
  
}

plot.simpleSmooth <- function(x,y,...) {
  plot(x$x,x$y,...)
}

predict.simpleSmooth <- function(object,newx,...) {
  if (missing(newx)) newx <- object$x
  phi <- cbind(rep(1,length(newx)),newx-0.5)
  R <- outer(newx,object$x,object$rk)
  if (!is.null(object$w)) as.vector(phi %*% object$d + R %*% (sqrt(object$w)*object$c))
  else as.vector(phi %*% object$d + R %*% object$c)
  ##as.vector(phi %*% object$d + R %*% object$c)
}



###################################################
### chunk number 82: pIRLS fct
###################################################
gs.iter <- function(y,x,lambda,previous,transform=NULL) {

  pred <- predict(previous,x)
  if (!is.null(transform)) pred <- transform(pred)
  w <- exp(pred)
  u <- - y + w
  pseudo.y <- pred - u / w
  ss_lambdaFixed(pseudo.y,x,lambda,w)
  
}


###################################################
### chunk number 83: Lambda Effect set-up
###################################################
gfit <- evalq(gfit,env=environment(n1CitrGSSPSTH0$lambdaFct))
Count <- gfit$mf$Count
Time <- gfit$mf$Time
refLambda <- 10^(gfit$nlambda)/length(Time)
T2 <- Time/ceiling(max(Time))
binSize <- diff(n1CitrGSSPSTH0$mids)[1]
nbT <- n1CitrGSSPSTH0$nbTrials
rawHist <- Count/nbT/binSize


###################################################
### chunk number 84: Lambda Effect
###################################################
f0 <- ss_lambdaFixed(sqrt(Count),T2,refLambda)
f1 <- gs.iter(Count,T2,refLambda,f0,function(x) 0.5*log(x))
fcurrent <- f1
for (i in 1:29) fcurrent <- gs.iter(Count,T2,refLambda,fcurrent)
gcurrent <- fcurrent
for (i in 1:29) gcurrent <- gs.iter(Count,T2,refLambda*1000,gcurrent)
hcurrent <- fcurrent
for (i in 1:29) hcurrent <- gs.iter(Count,T2,refLambda/1000,hcurrent)


###################################################
### chunk number 85: prepare IRLS illustration 0
###################################################
pdf(file="figs/lambdaEffect.pdf",width=8,height=8)


###################################################
### chunk number 86: IRLS illustration 0
###################################################
layout(matrix(1:4,2,2,byrow=TRUE))
par(mar=c(5,4,3,2))
plot(Time,rawHist,type="l",
     xlab="",ylab="Freq. (Hz)",
     main=expression(lambda == lambda[0]/1000))
mtext("A",side=3,adj=0,line=2)
abline(h=0)
lines(Time,exp(predict(hcurrent,T2))/nbT/binSize,col=2,lwd=2)
legend(0,100,
       c("\"raw\" data",
         "fit"),
       col=c(1,2),lty=c(1,1,1),lwd=c(2,2),bty="n")

plot(Time,rawHist,type="l",
     xlab="",ylab="",
     main=expression(lambda == lambda[0]))
mtext("B",side=3,adj=0,line=2)
abline(h=0)
lines(Time,exp(predict(fcurrent,T2))/nbT/binSize,col=2,lwd=2)
legend(0,100,
       c("\"raw\" data",
         "fit"),
       col=c(1,2),lty=c(1,1,1),lwd=c(2,2),bty="n")

plot(Time,rawHist,type="l",
     xlab="Time (s)",ylab="Freq. (Hz)",
     main=expression(lambda == 1000 * lambda[0]))
mtext("C",side=3,adj=0,line=2)
abline(h=0)
lines(Time,exp(predict(gcurrent,T2))/nbT/binSize,col=2,lwd=2)
legend(0,100,
       c("\"raw\" data",
         "fit"),
       col=c(1,2),lty=c(1,1,1),lwd=c(2,2),bty="n")

plot(Time,rawHist,type="n",
     xlab="Time (s)",ylab="",
     main=expression(paste(lambda," comparison"))
     )
mtext("D",side=3,adj=0,line=2)
abline(h=0)
lines(Time,exp(predict(hcurrent,T2))/nbT/binSize,col=1,lwd=2)
lines(Time,exp(predict(gcurrent,T2))/nbT/binSize,col=4,lwd=2)
lines(Time,exp(predict(fcurrent,T2))/nbT/binSize,col=2,lwd=1)
legend(0,100,
       c(expression(lambda == lambda[0] / 1000),
         expression(lambda == lambda[0]),
         expression(lambda == 1000*lambda[0])),
       col=c(1,2,4),lty=c(1,1,1),lwd=c(2,1,2),bty="n")


###################################################
### chunk number 87: close IRLS illustration 0
###################################################
dev.off()


###################################################
### chunk number 88: prepare simPrinciple fig
###################################################
pdf(file="figs/simPrinciple.pdf",width=16,height=10)


###################################################
### chunk number 89: simPrinciple
###################################################
set.seed(20061001,"Mersenne-Twister")
nlambda0 <- evalq(gfit,env=environment(n1CitrGSSPSTH0$lambdaFct))$nlambda
lambda0 <- (10^nlambda0)/length(n1CitrGSSPSTH0$mids)
s1 <- simulate(n1CitrGSSPSTH0)
s1GSSPSTH0 <- gsspsth0(s1)
nlambda <- evalq(gfit,env=environment(s1GSSPSTH0$lambdaFct))$nlambda
lambda <- (10^nlambda)/length(s1GSSPSTH0$mids)
xlim <- c(0,max(s1GSSPSTH0$mids))
ylim <- c(0,max(s1GSSPSTH0$ciUp))


###################################################
### chunk number 90: simPrinciple fig
###################################################
layout(matrix(c(1:3,rep(4,6)),nrow=3,byrow=TRUE))
par(mar=c(5,7,4,4))
plot(e070528citronellal[["neuron 1"]],main="e070528citronellal_n1",cex.main=2,cex.lab=2,ylab="")
mtext("A",side=3,adj=0,line=2)
plot(n1CitrGSSPSTH0$mids,
     n1CitrGSSPSTH0$freq,
     main="SPSTH",xlim=xlim,ylim=ylim,
     xlab="Time (s)",
     ylab="Freq. (Hz)",
     type="l",
     lwd=2,
     bty="n",
     xaxs="i",
     yaxs="i",cex.main=2,cex.lab=2
     )
mtext("B",side=3,adj=0,line=2)
abline(h=0,lwd=3)
cmd1 <- parse(text=paste("text(10,80,expression(log(lambda[0]) == ",round(log(lambda0),digits=1),"),cex=2)"))
eval(cmd1)
plot(s1,main="Simulated Data",cex.main=2,cex.lab=2,ylab="")
mtext("C",side=3,adj=0,line=2)
plot(xlim,ylim,type="n",
     xlab="Time (s)",
     ylab="Freq. (Hz)",
     main="Comparison between \"truth\" and estimate",
     bty="n",
     xaxs="i",
     yaxs="i",cex.main=2,cex.lab=2)
mtext("D",side=3,adj=0,line=2)
out <- n1CitrGSSPSTH0$freq<s1GSSPSTH0$ciLow | s1GSSPSTH0$ciUp < n1CitrGSSPSTH0$freq
nbOut <- sum(out)
groupId <- 1
group <- sapply(1:(length(n1CitrGSSPSTH0$mids[out])-1),
                function(idx) {
                  theG <- groupId
                  if (!diff(n1CitrGSSPSTH0$mids[out])[idx] < 0.05)
                    groupId <<- groupId+1
                  theG
                }
                )
group <- c(group,group[length(group)])
polygon(c(s1GSSPSTH0$mids,rev(s1GSSPSTH0$mids)),
        c(s1GSSPSTH0$ciLow,rev(s1GSSPSTH0$ciUp)),
        col="grey50",border=NA)
lines(n1CitrGSSPSTH0$mids,n1CitrGSSPSTH0$freq)
cmd2 <- parse(text=paste("text(10,80,expression(log(lambda) == ",round(log(lambda),digits=1),"),cex=2)"))
eval(cmd2)
text(2,80,paste(nbOut,"/",length(out),"points out"),cex=2)
abline(h=0,lwd=3)
invisible(sapply(1:max(group),
                 function(groupId) {
                   X <- s1GSSPSTH0$mids[out][group == groupId]
                   X1 <- min(X)
                   X2 <- max(X)
                   segments(X1,0,X2,0,lwd=4,col="white")
                 }
                 )
          )


###################################################
### chunk number 91: close simPrinciple fig
###################################################
dev.off()


###################################################
### chunk number 92: load summaryMC data
###################################################
load(paste(vigdir,"/summaryMC.rda",sep=""))


###################################################
### chunk number 93: define function to generate plots from the loaded data
###################################################
allSPSTHs <- function(object) {

  yMax <- max(sapply(object,function(l) max(l$ciUp)))
  xMax <- max(sapply(object,function(l) max(l$mids)))
  xlim <- c(0,xMax)
  ylim <- c(0,yMax)

  opar <- par(mar=c(2,1,2,1))
  on.exit(par(opar))
  layout(matrix(1:18,nrow=3))
  invisible(sapply(1:length(object),
                   function(idx) {
                     l <- object[[idx]]
                     plot(xlim,ylim,type="n",xaxt="n",yaxt="n",bty="n",
                          xlab="",ylab="",main=names(object)[idx])
                     segments(-0.5,10,-0.5,20,lwd=2)
                     segments(0,0,15,0)
                     polygon(c(l$mids,rev(l$mids)),
                             c(l$ciLow,rev(l$ciUp)),
                             col="grey50",border=NA)
                   }
                   )
            )
}


plot.BiasFig <- function(x,y,withLabels=TRUE,...) {

  ncol <- length(x)
  layout(matrix(1:(3*ncol),nrow=3))

  ylim1 <- c(min(sapply(x,function(l) min(l$eta[-c(1,length(l$eta))]))),
             max(sapply(x,function(l) max(l$eta[-c(1,length(l$eta))]))))
  ylim2 <- c(min(sapply(x,function(l) min(l$Bias[-c(1,length(l$eta))]))),
             max(sapply(x,function(l) max(l$Bias[-c(1,length(l$eta))]))))
  ylim3 <- c(min(sapply(x,function(l) 0.1*(floor(10*min(l$ECP[-c(1,length(l$ECP))]))))),
             1)
  
  invisible(lapply(1:ncol,
                   function(lIdx) {

                     eta <- x[[lIdx]]$eta
                     Bias <- x[[lIdx]]$Bias
                     eta.hat <- x[[lIdx]]$eta.hat
                     Out <- x[[lIdx]]$Out
                     ECP <- x[[lIdx]]$ECP
                     mcName <- names(x)[lIdx]
                     nbRep <- x[[lIdx]]$nbRep

                     xlim <- c(0,length(eta))
                     mcName2 <- paste("expression(paste(\"",mcName,": \"",",eta))",sep="")
                     mainCMD <- parse(text=mcName2)
                     plot(eta,type="l",
                          xlab="bin #",
                          ylab=expression(eta),
                          xaxs="i",yaxs="i",
                          main=eval(mainCMD),
                          xlim=xlim,
                          ylim=ylim1,
                          lwd=ifelse(ncol==1,2,1),
                          ...)
                     if (withLabels) {
                       if (ncol==1) mtext("A",side=3,adj=0,line=2)
                       else mtext(paste(LETTERS[lIdx],1,sep=""),side=3,adj=0,line=2)
                     }
                     plot(Bias,type="l",
                          xlab="bin #",
                          ylab=expression(paste(eta," - E(",hat(eta),")")),
                          xaxs="i",yaxs="i",xlim=xlim,
                          ylim=ylim2,
                          main=ifelse(ncol==1,
                            paste("Estimated Pointwise Bias Over",nbRep,"MC Trials"),
                            "Est. Pointwise Bias"),
                          lwd=ifelse(ncol==1,2,1),
                          ...)
                     if (withLabels) {
                       if (ncol==1) mtext("B",side=3,adj=0,line=2)
                       else mtext(paste(LETTERS[lIdx],2,sep=""),side=3,adj=0,line=2)
                     }
                     abline(h=0)
                     plot(ECP,xlab="bin #",ylab="Coverage",
                          type="l",xaxs="i",yaxs="i",
                          xlim=xlim,
                          main=ifelse(ncol==1,
                            paste("Estimated Pointwise Coverage Prob. for 95 % Confidence Intervals Over",
                                  nbRep,
                                  "MC Trials"),
                            "Est. Pointwise Cov. Prob."),
                          ylim=ylim3,
                          lwd=ifelse(ncol==1,2,1),
                          ...
                          )
                     if (withLabels) {
                       if (ncol==1) mtext("C",side=3,adj=0,line=2)
                       else mtext(paste(LETTERS[lIdx],3,sep=""),side=3,adj=0,line=2)
                     }
                     abline(h=0.95,lty=2)
                   }
                   )
            )
  
}

plot.mcSummary <- function(x,y,outline=TRUE,...) {

  nbOut <- unlist(lapply(x, function(l) l$nbOut/length(l$eta)))
  lambda <- unlist(lapply(x, function(l) (10^l$lambda)/length(l$eta)))
  ref <- factor(unlist(lapply(1:length(x),
                              function(idx) rep(idx,x[[idx]]$nbRep)
                            )
                     ),
                labels=names(x)
                )
  myDF <- data.frame(ref,nbOut,lambda)

  layout(matrix(1:2,nrow=2))
  opar <- par(mar=c(1,4,3,2))
  on.exit(par(opar))
  boxplot(log(lambda) ~ ref,data=myDF,
          outline=outline,
          ylab=expression(log(lambda)),
          main="Smoothing Parameter Estimation",
          xaxt="n")
  mtext("A",side=3,adj=0,line=1)
  invisible(sapply(1:length(x),
                   function(idx) {
                     rl <- 10^(x[[idx]]$refLambda)/length(x[[idx]]$eta)
                     points(idx,log(rl),pch=19,col="grey50")
                   }
                   )
            )
  par(las=2,mar=c(9,4,3,2))
  boxplot(1-nbOut ~ ref,data=myDF,ylab="Coverage",
          outline=outline,
          main="Estimated Average Coverage Prob.")
  mtext("B",side=3,las=1,line=1,adj=0)
  abline(h=0.95,col="grey50",lty=2,lwd=2)
  invisible(par(opar))
  
}


###################################################
### chunk number 94: prepare allSPSTHs fig
###################################################
pdf(file="figs/allSPSTHs.pdf",width=12,height=12)


###################################################
### chunk number 95: allSPSTHs fig
###################################################
allSPSTHs(summaryMC)


###################################################
### chunk number 96: close allSPSTHs fig
###################################################
dev.off()


###################################################
### chunk number 97: prepare LCI fig
###################################################
pdf(file="figs/LCI.pdf",width=10,height=10)


###################################################
### chunk number 98: LCI fig
###################################################
plot.mcSummary(summaryMC)


###################################################
### chunk number 99: close LCI fig
###################################################
dev.off()


###################################################
### chunk number 100: prepare BCP fig
###################################################
pdf(file="figs/BCP.pdf",width=10,height=10)


###################################################
### chunk number 101: BCP fig
###################################################
badOnes <- sort.int(sapply(summaryMC, function(l) min(l$ECP[-c(1,length(l$ECP))])),ind=TRUE)$ix[1:3]
plot.BiasFig(summaryMC[badOnes])


###################################################
### chunk number 102: close BCP fig
###################################################
dev.off()


###################################################
### chunk number 103: reset options
###################################################
options(width=80)


